@@ -6,13 +6,13 @@ from qrunner.core.android.element import AndroidElement
 from qrunner.core.ios.driver import IosDriver
 from qrunner.core.ios.element import IosElement
 from qrunner.core.h5.driver import H5Driver
-from qrunner.core.browser.driver import BrowserDriver
-from qrunner.core.browser.element import WebElement
+from qrunner.core.web.driver import WebDriver
+from qrunner.core.web.element import WebElement
 from qrunner.utils.log import logger
 from qrunner.utils.decorate import *
 from qrunner.utils.mock import mock, mock_en, RandomData, CommonData
 from qrunner.utils.config import conf
 
-__version__ = "0.9.29"
+__version__ = "0.9.37"
 __description__ = "全栈自动化测试框架"
 
