@@ -8,8 +8,8 @@ from qrunner.core.android.driver import AndroidDriver
 from qrunner.core.android.element import AndroidElement
 from qrunner.core.ios.driver import IosDriver
 from qrunner.core.ios.element import IosElement
-from qrunner.core.browser.driver import BrowserDriver
-from qrunner.core.browser.element import WebElement
+from qrunner.core.web.driver import WebDriver
+from qrunner.core.web.element import WebElement
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
 
@@ -37,10 +37,10 @@ class TestCase(HttpRequest):
     @classmethod
     def setup_class(cls):
         # 从配置文件中获取浏览器相关配置（为了支持并发执行）
-        platform = conf.get_name('common', 'platform')
-        serial_no = conf.get_name('app', 'serial_no')
-        pkg_name = conf.get_name('app', 'pkg_name')
-        browser_name = conf.get_name('web', 'browser_name')
+        platform = conf.get_item('common', 'platform')
+        serial_no = conf.get_item('app', 'serial_no')
+        pkg_name = conf.get_item('app', 'pkg_name')
+        browser_name = conf.get_item('web', 'browser_name')
 
         # 初始化driver
         cls.driver = None
@@ -58,9 +58,9 @@ class TestCase(HttpRequest):
             else:
                 logger.info('serial_no为空')
                 sys.exit()
-        elif platform == 'browser':
+        elif platform == 'web':
             logger.info('初始化 Selenium driver')
-            cls.driver = BrowserDriver(browser_name)
+            cls.driver = WebDriver(browser_name)
         elif platform == 'api':
             pass
         else:
@@ -71,7 +71,7 @@ class TestCase(HttpRequest):
     @classmethod
     def teardown_class(cls):
         # 关闭浏览器
-        if isinstance(cls().driver, BrowserDriver):
+        if isinstance(cls().driver, WebDriver):
             cls().driver.quit()
         cls().end_class()
 
@@ -91,8 +91,9 @@ class TestCase(HttpRequest):
         logger.debug(f"[end_time]: {time.strftime('%Y-%m-%d %H:%M:%S')}")
         take_time = time.time() - self.start_time
         logger.debug("[run_time]: {:.2f} s".format(take_time))
-        logger.debug("[截图]: 用例执行结束")
-        self.driver.screenshot('[用例执行结束]')
+        if isinstance(self.driver, AndroidDriver) or isinstance(self.driver, IosDriver) or isinstance(self.driver, WebDriver):
+            logger.debug("[截图]: 用例执行结束")
+            self.driver.screenshot('[用例执行结束]')
 
     def setup_method(self):
         # 启动应用
@@ -123,25 +124,35 @@ class TestCase(HttpRequest):
             element = AndroidElement(self.driver, **kwargs)
         elif isinstance(self.driver, IosDriver):
             element = IosElement(self.driver, **kwargs)
-        elif isinstance(self.driver, BrowserDriver):
+        elif isinstance(self.driver, WebDriver):
             element = WebElement(self.driver, **kwargs)
         else:
             platform = conf.get('common', 'platform')
-            logger.info(f'不支持的平台: {platform}，暂时只支持android、ios、browser')
+            logger.info(f'不支持的平台: {platform}，暂时只支持android、ios、web')
             sys.exit()
         return element
 
+    def screenshot(self, desc, element):
+        """截图并标记元素位置"""
+        platform = conf.get_item('common', 'platform')
+        if platform == 'web':
+            self.driver.execute_js("arguments[0].style.border='3px solid red'", element.get_element())
+            self.driver.screenshot(desc)
+        else:
+            self.driver.screenshot(desc, rect=element.rect)
+
     def click(self, **kwargs):
         """点击"""
         desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc}]'
         with step(step_desc):
             try:
-                self.element(**kwargs).click()
+                element = self.element(**kwargs)
+                element.click()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def click_exists(self, **kwargs):
         """存在才点击"""
@@ -149,11 +160,12 @@ class TestCase(HttpRequest):
         step_desc = f'[存在才点击 {desc}]'
         with step(step_desc):
             try:
-                self.element(**kwargs).click_exists()
+                element = self.element(**kwargs)
+                element.click_exists()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def set_text(self, text, **kwargs):
         """输入"""
@@ -161,11 +173,12 @@ class TestCase(HttpRequest):
         step_desc = f'[点击 {desc} 后输入 {text}]'
         with step(step_desc):
             try:
-                self.element(**kwargs).set_text(text)
+                element = self.element(**kwargs)
+                element.set_text(text)
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def set_password(self, text, **kwargs):
         """输入密码，仅安卓使用"""
@@ -174,15 +187,16 @@ class TestCase(HttpRequest):
         with step(step_desc):
             try:
                 if isinstance(self.driver, AndroidDriver):
-                    self.element(**kwargs).click()
+                    element = self.element(**kwargs)
+                    element.click()
                     self.driver.set_password(text)
                 else:
                     platform = conf.get('common', 'platform')
                     logger.debug(f'仅支持安卓平台，当前平台为: {platform}')
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def clear_text(self, **kwargs):
         """清除输入框"""
@@ -190,11 +204,12 @@ class TestCase(HttpRequest):
         step_desc = f'[点击 {desc} 后清除文本]'
         with step(step_desc):
             try:
-                self.element(**kwargs).clear_text()
+                element = self.element(**kwargs)
+                element.clear_text()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def get_text(self, **kwargs):
         """获取文本属性"""
@@ -202,11 +217,10 @@ class TestCase(HttpRequest):
         step_desc = f'[获取 {desc} 的文本]'
         with step(step_desc):
             try:
-                return self.element(**kwargs).text
+                element = self.element(**kwargs)
+                return element.text
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
 
     def assertText(self, expect_value=None, timeout=5, desc=''):
         """断言页面包含文本"""
@@ -260,7 +274,8 @@ class TestCase(HttpRequest):
             try:
                 for _ in range(timeout + 1):
                     try:
-                        assert self.element(**kwargs).exists(), f'元素 {kwargs} 不存在'
+                        element = self.element(**kwargs)
+                        assert element.exists(), f'元素 {kwargs} 不存在'
                         break
                     except AssertionError:
                         time.sleep(1)
@@ -268,8 +283,8 @@ class TestCase(HttpRequest):
                     assert self.element(**kwargs).exists(), f'元素 {kwargs} 不存在'
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def assertNotElement(self, timeout=5, **kwargs):
         """断言元素不存在"""
@@ -296,7 +311,7 @@ class TestCase(HttpRequest):
         step_desc = f'[打开 {desc}]'
         with step(step_desc):
             try:
-                self.driver.open_url(url, login=login, desc=desc)
+                self.driver.open_url(url, login=login)
             except Exception as e:
                 raise AssertionError(str(e))
             finally:
@@ -308,11 +323,12 @@ class TestCase(HttpRequest):
         step_desc = f'[点击 {desc}]'
         with step(step_desc):
             try:
-                self.driver.click(self.element(**kwargs))
+                element = self.element(**kwargs)
+                self.driver.click(element)
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def accept_alert(self, desc=''):
         """同意弹窗"""
@@ -642,7 +658,7 @@ class Page:
 
     def element(self, **kwargs):
         """
-        根据
+        定位元素
         :param kwargs: 元素定位方式
         :return: 根据平台返回对应的元素
         """
@@ -650,57 +666,70 @@ class Page:
             element = AndroidElement(self.driver, **kwargs)
         elif isinstance(self.driver, IosDriver):
             element = IosElement(self.driver, **kwargs)
-        elif isinstance(self.driver, BrowserDriver):
+        elif isinstance(self.driver, WebDriver):
             element = WebElement(self.driver, **kwargs)
         else:
             platform = conf.get('common', 'platform')
-            logger.info(f'不支持的平台: {platform}，暂时只支持android、ios、browser')
+            logger.info(f'不支持的平台: {platform}，暂时只支持android、ios、web')
             sys.exit()
         return element
 
-    def click(self, element):
+    def screenshot(self, desc, element):
+        """截图并标记元素位置"""
+        platform = conf.get_item('common', 'platform')
+        if platform == 'web':
+            self.driver.execute_js("arguments[0].style.border='3px solid red'", element.get_element())
+            self.driver.screenshot(desc)
+        else:
+            self.driver.screenshot(desc, rect=element.rect)
+
+    def click(self, **kwargs):
         """点击"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc}]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 element.click()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def click_exists(self, element):
+    def click_exists(self, **kwargs):
         """存在才点击"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[存在才点击 {desc}]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 element.click_exists()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def set_text(self, text, element):
+    def set_text(self, text, **kwargs):
         """输入"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc} 后输入 {text}]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 element.set_text(text)
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def set_password(self, text, element):
+    def set_password(self, text, **kwargs):
         """输入密码，仅安卓使用"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc} 后输入 {text}]'
         with step(step_desc):
             try:
                 if isinstance(self.driver, AndroidDriver):
+                    element = self.element(**kwargs)
                     element.click()
                     self.driver.set_password(text)
                 else:
@@ -708,32 +737,32 @@ class Page:
                     logger.debug(f'仅支持安卓平台，当前平台为: {platform}')
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def clear_text(self, element):
+    def clear_text(self, **kwargs):
         """清除输入框"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc} 后清除文本]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 element.clear_text()
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def get_text(self, element):
+    def get_text(self, **kwargs):
         """获取文本属性"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[获取 {desc} 的文本]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 return element.text
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
 
     def assertText(self, expect_value=None, timeout=5, desc=''):
         """断言页面包含文本"""
@@ -779,39 +808,40 @@ class Page:
             finally:
                 self.driver.screenshot(step_desc)
 
-    def assertElement(self, element, timeout=5):
+    def assertElement(self, timeout=5, **kwargs):
         """断言元素存在"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[断言控件 {desc} 存在]'
         with step(step_desc):
             try:
                 for _ in range(timeout + 1):
                     try:
-                        assert element.exists(), f'元素 {desc} 不存在'
+                        element = self.element(**kwargs)
+                        assert element.exists(), f'元素 {kwargs} 不存在'
                         break
                     except AssertionError:
                         time.sleep(1)
                 else:
-                    assert element.exists(), f'元素 {desc} 不存在'
+                    assert self.element(**kwargs).exists(), f'元素 {kwargs} 不存在'
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
-    def assertNotElement(self, element, timeout=5):
+    def assertNotElement(self, timeout=5, **kwargs):
         """断言元素不存在"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[断言控件 {desc} 不存在]'
         with step(step_desc):
             try:
                 for _ in range(timeout + 1):
                     try:
-                        assert not element.exists(), f'元素 {desc} 仍然存在'
+                        assert not self.element(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
                         break
                     except AssertionError:
                         time.sleep(1)
                 else:
-                    assert not element.exists(), f'元素 {desc} 仍然存在'
+                    assert not self.element(**kwargs).exists(), f'元素 {kwargs} 仍然存在'
             except Exception as e:
                 raise AssertionError(str(e))
             finally:
@@ -823,23 +853,24 @@ class Page:
         step_desc = f'[打开 {desc}]'
         with step(step_desc):
             try:
-                self.driver.open_url(url, login=login, desc=desc)
+                self.driver.open_url(url, login=login)
             except Exception as e:
                 raise AssertionError(str(e))
             finally:
                 self.driver.screenshot(step_desc)
 
-    def click_by_js(self, element):
+    def click_by_js(self, **kwargs):
         """通过js的方式点击"""
-        desc = element.desc
+        desc = kwargs.get('desc', '')
         step_desc = f'[点击 {desc}]'
         with step(step_desc):
             try:
+                element = self.element(**kwargs)
                 self.driver.click(element)
             except Exception as e:
                 raise AssertionError(str(e))
-            finally:
-                self.driver.screenshot(step_desc)
+            else:
+                self.screenshot(step_desc, element)
 
     def accept_alert(self, desc=''):
         """同意弹窗"""
@@ -964,3 +995,6 @@ class Page:
                 self.driver.screenshot(step_desc)
 
 
+
+
+
