@@ -4,6 +4,7 @@ import allure
 import uiautomator2 as u2
 from qrunner.utils.config import conf
 from qrunner.utils.log import logger
+from baseImage import Image, Rect
 
 
 class AndroidDriver(object):
@@ -18,10 +19,10 @@ class AndroidDriver(object):
 
     def __init__(self, serial_no=None, pkg_name=None):
         if serial_no is None:
-            serial_no = conf.get_name('app', 'serial_no')
+            serial_no = conf.get_item('app', 'serial_no')
         self.serial_no = serial_no
         if pkg_name is None:
-            pkg_name = conf.get_name('app', 'pkg_name')
+            pkg_name = conf.get_item('app', 'pkg_name')
         self.pkg_name = pkg_name
 
         logger.info(f'启动 android driver for {self.serial_no}')
@@ -222,10 +223,11 @@ class AndroidDriver(object):
         logger.info(is_running)
         return is_running
 
-    def screenshot(self, file_name):
+    def screenshot(self, file_name, rect=None):
         """
         截图并保存到预定路径并上传到allure报告
         @param file_name: foo.png or fool
+        @param rect: 需要标记控件的左上角坐标和宽高
         @return:
         """
         # 把文件名处理成test.png的样式
@@ -240,6 +242,13 @@ class AndroidDriver(object):
                                  f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.screenshot(file_path)
+
+        # 给图片打上标记
+        if rect is not None:
+            img = Image(file_path)
+            img.rectangle(Rect(*rect), color=(0, 0, 255), thickness=3)
+            img.imwrite(file_path)
+
         # 截图并上传到allure报告
         logger.info(f'截图上传至allure报告')
         allure.attach.file(file_path,
