@@ -1,4 +1,5 @@
 import inspect
+import json
 import os
 import time
 from multiprocessing.dummy import Pool as ThreadPool
@@ -16,7 +17,7 @@ class AndroidElement(object):
     """
     安卓元素定义
     """
-    def __init__(self, driver=None, *args, **kwargs):
+    def __init__(self, driver=None, **kwargs):
         # 从kwargs中删掉并返回index
         self._index = kwargs.pop('index', 0)
         self.desc = kwargs.pop('desc', '')
@@ -47,13 +48,9 @@ class AndroidElement(object):
             element.click_exists(timeout=1)
 
         # 多线程执行点击过程
-        alert_str = conf.get_name('app', 'android_alert')
-        logger.debug(f'处理异常弹窗: {alert_str}')
-        try:
-            alert_list = alert_str.split(',')
-        except:
-            alert_list = []
-        pool = ThreadPool(10)
+        alert_list = conf.get_item('app', 'android_alert')
+        print(f'异常弹窗列表: {alert_list}')
+        pool = ThreadPool(len(alert_list))
         if alert_list:
             pool.map(click_alert, alert_list)
         else:
@@ -111,6 +108,16 @@ class AndroidElement(object):
         logger.info(f'获取元素: {self._kwargs} 的坐标')
         return self.get_element().info.get('bounds')
 
+    @property
+    def rect(self):
+        logger.info(f'获取元素: {self._kwargs} 左上角的坐标以及宽高')
+        bounds = self.get_element().info.get('bounds')
+        x = bounds['left']
+        y = bounds['top']
+        width = bounds['right'] - x
+        height = bounds['bottom'] - y
+        return [x, y, width, height]
+
     @property
     def visibleBounds(self):
         logger.info(f'获取元素: {self._kwargs} 的可见坐标')
@@ -154,13 +161,16 @@ class AndroidElement(object):
         logger.info(f'判断元素是否存在: {self._kwargs},{self._index}')
         element = self._find_element(retry=0, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'元素定位失败')
+            # self._driver.screenshot(f'元素定位失败')
             return False
         return True
 
     def click(self):
         logger.info(f'点击元素: {self._kwargs},{self._index}')
-        self.get_element().click()
+        element = self.get_element()
+        print('点击元素')
+        element.click()
+        print('点击成功')
 
     def click_exists(self):
         logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
