@@ -22,7 +22,7 @@ def request(func):
             url = kwargs.get("url", "")
 
         if "http" not in url:
-            base_url = conf.get_name('common', 'base_url')
+            base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
                 url = parse.urljoin(base_url, url)
             else:
@@ -38,11 +38,11 @@ def request(func):
         auth = kwargs.get("auth", "")
 
         # 处理请求头
-        headers: dict = json_util.loads(conf.get_name('common', 'headers'))  # 从配置文件拿到登录用户请求头
+        headers = conf.get_item('common', 'headers')  # 从配置文件拿到登录用户请求头
         # 如果login=False，从请求头中删掉登录态相关的键值对
         login_status = kwargs.get('login', True)
         if not login_status:
-            login_key = json_util.loads(conf.get_name('api', 'login_key'))
+            login_key = conf.get_item('api', 'login_key')
             for key in login_key:
                 headers.pop(key)
         # 把上层请求方法的headers参数更新到headers里面
@@ -51,7 +51,7 @@ def request(func):
 
         # 设置请求超时时间为5s
         try:
-            timeout_default = int(conf.get_name('common', 'timeout'))
+            timeout_default = int(conf.get_item('common', 'timeout'))
         except:
             timeout_default = 10
         timeout_set = kwargs.pop("timeout", None)
@@ -72,14 +72,11 @@ def request(func):
         if cookies != "":
             logger.debug(f"[cookies]:\n {json_util.dumps(cookies)} \n")
         if params != "":
-            logger.debug(f"[params-json]:\n {json_util.dumps(params)} \n")
-            logger.debug(f"[params-python]:\n {params} \n")
+            logger.debug(f"[params]:\n json: {json_util.dumps(params)} \n python: {params}")
         if data != "":
-            logger.debug(f"[data-json]:\n {json_util.dumps(data)} \n")
-            logger.debug(f"[data-python]:\n {data} \n")
+            logger.debug(f"[data]:\n json: {json_util.dumps(data)} \n python: {data}")
         if json != "":
-            logger.debug(f"[json-json]:\n {json_util.dumps(json)} \n")
-            logger.debug(f"[json-python]:\n {json_util.dumps(json)} \n")
+            logger.debug(f"[json]:\n json: {json_util.dumps(json)} \n python: {json}")
 
         # running function
         r = func(*args, **kwargs)
@@ -114,7 +111,7 @@ class HttpRequest(object):
     @request
     def get(self, url, params=None, login=True, **kwargs):
         if "http" not in url:
-            base_url = eval(conf.get_name('common', 'base_url'))
+            base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
                 url = parse.urljoin(base_url, url)
             else:
@@ -125,7 +122,7 @@ class HttpRequest(object):
     @request
     def post(self, url, data=None, json=None, login=True, **kwargs):
         if "http" not in url:
-            base_url = conf.get_name('common', 'base_url')
+            base_url = conf.get_item('common', 'base_url')
             logger.debug(base_url)
             if 'http' in base_url:
                 url = parse.urljoin(base_url, url)
@@ -137,7 +134,7 @@ class HttpRequest(object):
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
         if "http" not in url:
-            base_url = conf.get_name('common', 'base_url')
+            base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
                 url = parse.urljoin(base_url, url)
             else:
@@ -150,7 +147,7 @@ class HttpRequest(object):
     @request
     def delete(self, url, login=True, **kwargs):
         if "http" not in url:
-            base_url = conf.get_name('common', 'base_url')
+            base_url = conf.get_item('common', 'base_url')
             if 'http' in base_url:
                 url = parse.urljoin(base_url, url)
             else:
