@@ -1,7 +1,9 @@
+import json
 import os
 import sys
 import time
 import allure
+from baseImage import Image, Rect
 from selenium import webdriver
 from qrunner.utils.config import conf
 from qrunner.utils.log import logger
@@ -38,23 +40,45 @@ class H5Driver(object):
         serial_no = android_driver.serial_no
         pkg_name = android_driver.pkg_name
 
+        # # 判断应用是否已启动
+        # pid = android_driver.wait_app_running()
+        # if pid:
+        #     logger.debug('应用已启动')
+        # else:
+        #     logger.debug('应用未启动，h5Driver初始化失败')
+        #     sys.exit()
+
         logger.info(f'启动H5Driver for {serial_no}')
         options = webdriver.ChromeOptions()
         options.add_experimental_option('androidDeviceSerial', serial_no)
         options.add_experimental_option('androidPackage', pkg_name)
         options.add_experimental_option('androidUseRunningApp', True)
         options.add_experimental_option('androidProcess', pkg_name)
-        version = conf.get_name('app', 'webview_version')
-        try:
-            path_ = ChromeDriverManager(version=version).install()
-        except Exception as e:
-            logger.debug(f'安装chromdriver {version} 失败: {e}')
+        version_list = conf.get_item('app', 'webview_version')
+        for version in version_list:
+            try:
+                path_ = ChromeDriverManager(version=version).install()
+                self.d = webdriver.Chrome(
+                    executable_path=path_,
+                    options=options
+                )
+                logger.debug('h5Driver初始化成功')
+                logger.debug(f'版本 {version} 配对成功')
+                break
+            except:
+                logger.debug(f'版本 {version} 配对失败')
+                continue
+        else:
+            logger.debug(f'配置的版本号都不对: {version_list}')
             sys.exit()
-        self.d = webdriver.Chrome(
-            executable_path=path_,
-            options=options
-        )
-        self.d.set_page_load_timeout(60)
+
+        # 设置页面加载超时时间
+        try:
+            timeout = int(conf.get_item('common', 'timeout'))
+        except:
+            pass
+        else:
+            self.d.set_page_load_timeout(timeout)
 
     # @staticmethod
     # def get_instance(cls, serial_no=None):
@@ -71,10 +95,11 @@ class H5Driver(object):
         logger.info('返回上一页')
         self.d.back()
 
-    def screenshot(self, file_name):
+    def screenshot(self, file_name, rect=None):
         """
         截图并保存到预定路径并上传到allure报告
         @param file_name: foo.png or fool
+        @param rect: 列表
         @return:
         """
         # 把文件名处理成test.png的样式
@@ -89,6 +114,13 @@ class H5Driver(object):
                                  f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.save_screenshot(file_path)
+
+        # 标记
+        if rect is not None:
+            img = Image(file_path)
+            img.rectangle(Rect(*rect), color=(0, 0, 255), thickness=3)
+            img.imwrite(file_path)
+
         # 截图并上传到allure报告
         logger.info(f'截图上传至allure报告')
         allure.attach.file(file_path,
