@@ -5,6 +5,8 @@ import time
 import allure
 import requests
 import wda
+from baseImage import Image, Rect
+
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
 
@@ -67,10 +69,10 @@ class IosDriver(object):
 
     def __init__(self, serial_no=None, pkg_name=None):
         if not serial_no:
-            serial_no = conf.get_name('app', 'serial_no')
+            serial_no = conf.get_item('app', 'serial_no')
         self.serial_no = serial_no
         if not pkg_name:
-            pkg_name = conf.get_name('app', 'pkg_name')
+            pkg_name = conf.get_item('app', 'pkg_name')
         self.bundle_id = pkg_name
         logger.info(self.bundle_id)
         logger.info(f'启动 ios driver for {self.serial_no}')
@@ -165,10 +167,11 @@ class IosDriver(object):
         logger.info(f'输入: {value}')
         self.d.send_keys(value)
 
-    def screenshot(self, file_name):
+    def screenshot(self, file_name, rect=None):
         """
         截图并保存到预定路径并上传到allure报告
         @param file_name: foo.png or fool
+        @param rect: 需要标记控件左上角坐标以及宽高
         @return:
         """
         # 把文件名处理成test.png的样式
@@ -183,6 +186,13 @@ class IosDriver(object):
                                  f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
         self.d.screenshot(file_path)
+
+        # 标记
+        if rect is not None:
+            img = Image(file_path)
+            img.rectangle(Rect(*rect), color=(0, 0, 255), thickness=3)
+            img.imwrite(file_path)
+
         # 截图并上传到allure报告
         logger.info(f'截图上传至allure报告')
         allure.attach.file(file_path,
