@@ -26,7 +26,7 @@ class TestMain(object):
                  report_path='report'
                  ):
         """
-        :param platform str: 平台，如browser、android、ios、api
+        :param platform str: 平台，如web、android、ios、api
         :param serial_no str: 设备id，如UJK0220521066836、00008020-00086434116A002E
         :param pkg_name str: 应用包名，如com.qizhidao.clientapp、com.qizhidao.company
         :param browser_name str: 浏览器类型，如chrome、其他暂不支持
@@ -58,26 +58,26 @@ class TestMain(object):
 
         # 将数据写入全局变量
         if self.platform is not None:
-            conf.set_name('common', 'platform', self.platform)
+            conf.set_item('common', 'platform', self.platform)
         if self.serial_no is not None:
-            conf.set_name('app', 'serial_no', self.serial_no)
+            conf.set_item('app', 'serial_no', self.serial_no)
         if self.pkg_name is not None:
-            conf.set_name('app', 'pkg_name', self.pkg_name)
+            conf.set_item('app', 'pkg_name', self.pkg_name)
         if self.browser_name is not None:
-            conf.set_name('web', 'browser_name', self.browser_name)
+            conf.set_item('web', 'browser_name', self.browser_name)
         if self.base_url is not None:
-            conf.set_name('common', 'base_url', self.base_url)
+            conf.set_item('common', 'base_url', self.base_url)
         else:
-            if self.platform == 'api' or self.platform == 'browser':
+            if self.platform == 'api' or self.platform == 'web':
                 print('base_url未配置，请配置后重新执行~')
                 sys.exit()
         if self.headers is not None:
-            conf.set_name('common', 'headers', json.dumps(self.headers))
+            conf.set_item('common', 'headers', headers)
         if login_key is not None:
-            conf.set_name('api', 'login_key', json.dumps(self.login_key))
+            conf.set_item('api', 'login_key', login_key)
         if self.timeout is not None:
-            conf.set_name('common', 'timeout', self.timeout)
-        conf.set('common', 'report_path', self.report_path)
+            conf.set_item('common', 'timeout', self.timeout)
+        conf.set_item('common', 'report_path', self.report_path)
 
         # 执行用例
         logger.info('执行用例')
@@ -90,7 +90,7 @@ class TestMain(object):
         if self.case_path:
             cmd_list.insert(0, self.case_path)
         if self.concurrent:
-            if self.platform == 'browser' or self.platform == 'api':
+            if self.platform == 'web' or self.platform == 'api':
                 cmd_list.insert(1, '-n')
                 cmd_list.insert(2, 'auto')
                 cmd_list.insert(3, '--dist=loadscope')
@@ -101,7 +101,7 @@ class TestMain(object):
         pytest.main(cmd_list)
 
         # 用例完成后操作
-        conf.set_name('common', 'headers', json.dumps({}))  # 清除登录态
+        conf.set_item('common', 'headers', {})  # 清除登录态
         os.system(f'allure generate allure-results -o {self.report_path} --clean')  # 生成报告
 
 
