@@ -1,60 +1,49 @@
 import os.path
 import sys
 
-api_run_content = """
-import qrunner
+api_run_content = """import qrunner
 
 
 if __name__ == '__main__':
-    base_url = 'https://www.qizhidao.com'
     qrunner.main(
-        case_path='test_dir',
         platform='api',
-        base_url=base_url,
+        base_url='https://www.qizhidao.com'
     )
 """
 
-android_run_content = """
-import qrunner
+android_run_content = """import qrunner
 
 
 if __name__ == '__main__':
     qrunner.main(
-        case_path = 'test_dir',
         platform='android',
         serial_no='UJK0220521066836',
         pkg_name='com.qizhidao.clientapp'
     )
 """
 
-ios_run_content = """
-import qrunner
+ios_run_content = """import qrunner
 
 
 if __name__ == '__main__':
     qrunner.main(
-        case_path = 'test_dir',
         platform='ios',
         serial_no='00008101-000E646A3C29003A',
         pkg_name='com.qizhidao.company'
     )
 """
 
-browser_run_content = """
-import qrunner
+browser_run_content = """import qrunner
 
 
 if __name__ == '__main__':
     qrunner.main(
-        case_path = 'test_dir',
-        platform='browser',
-        browser_name='chrome',
+        platform='web',
         base_url='https://patents-pre.qizhidao.com'
     )
 """
 
-case_content_android = """
-import qrunner
+case_content_android = """import qrunner
 
 
 @qrunner.story('首页')
@@ -67,8 +56,7 @@ class TestAdrSample(qrunner.TestCase):
         self.assertText('我的订单', desc='我的订单标题')
 """
 
-case_content_ios = """
-import qrunner
+case_content_ios = """import qrunner
 
 
 @qrunner.story('首页')
@@ -80,8 +68,7 @@ class TestIosSample(qrunner.TestCase):
         self.assertText('我的订单', desc='我的订单标题')
 """
 
-case_content_web = """
-import qrunner
+case_content_web = """import qrunner
 
 
 @qrunner.story('专利检索')
@@ -95,8 +82,7 @@ class TestWebSample(qrunner.TestCase):
         self.assertTitle('无人机专利检索-企知道', desc='专利搜索页')
 """
 
-case_content_api = """
-import qrunner
+case_content_api = """import qrunner
 
 
 @qrunner.story('PC站首页')
@@ -118,8 +104,7 @@ ignore_content = "\n".join(
     ["__pycache__/*", "*.pyc", ".idea/*", ".DS_Store", "allure-results", "report"]
 )
 
-data_content = """
-{
+data_content = """{
   "card_type": [0, 1, 2]
 }
 """
