@@ -28,6 +28,11 @@ def title(text):
     return allure.title(text)
 
 
+# 报告步骤
+def step(text):
+    return allure.step(text)
+
+
 def order(index):
     """
     指定用例执行顺序
