@@ -47,7 +47,7 @@ class Robot:
 
     # 从allure报告中获取数据并发送消息
     def send_report(self, msg_title, report_url):
-        report_path = conf.get('common', 'report_path')
+        report_path = conf.get_item('common', 'report_path')
         allure_data = AllureData(report_path).get_basic_info()
         total = allure_data.get('total')
         passed = allure_data.get('passed')
