@@ -56,21 +56,15 @@ class BaseDB(object):
         finally:
             self.close()
 
-    def select(self, sql, one=True):
+    def select(self, sql):
         try:
             self.cursor.execute(sql)
         except Exception as e:
             print(f'查询失败: {e}')
         else:
             print('查询成功,', end=' ')
-            if one:
-                items = list(self.cursor.fetchone())
-                print(f'共查询出: 1 行数据, 第一行数据如下:')
-                print(f'{items}\n')
-            else:
-                items = list(self.cursor.fetchall())
-                print(f'共查询出: {len(items)} 行数据, 第一行数据如下:')
-                print(f'{items[0]}\n')
+            items = list(self.cursor.fetchall())
+            print(f'共查询出: {len(items)} 行数据')
             return items
         finally:
             self.close()
